/*
 * Change_Interval_Blink_LED_ST.c
 *
 *  Created on: 2024/12/19
 *      Author: egaono-electronics
 */

#include "Change_Interval_Blink_LED_ST.h"

#include "Detects_Pressed_USW.h"



//-------------------------------------
// ST LED点滅フラグ
//-------------------------------------
//  0 : 点灯1000mSec / 消灯2000mSec
//  1 : 点灯100mSec / 消灯100mSec
//  2 : 点灯200mSec / 消灯200mSec
//  3 : 点灯300mSec / 消灯300mSec
//  4 : 点灯400mSec / 消灯400mSec
//  5 : 点灯500mSec / 消灯500mSec
//-------------------------------------
int16_t GLB_int16_Flag_Blink_LED_ST = 0;



//---------------------------------------------------------
// ST LED点滅インターバル変更
//----------------------------------------------------------
// 引数:
// uint8_t *puint8_JobNum : 処理番号を格納する変数のポインタ

// struct sParam_Blink_LED_ST *pstructParam_Blink_LED_ST :
//              ST LED点滅用パラメータの構造体のポインタ


// 戻り値:
//   -1 : 処理中
//    0 : OK終了
//    1 : NG
//----------------------------------------------------------
int16_t Change_Interval_Blink_LED_ST(uint8_t *puint8_JobNum,
            struct sParam_Blink_LED_ST *pstructParam_Blink_LED_ST)
{
  static uint8_t STC_uint8_JobNum_USW;  // USERスイッチ検出処理番号

  int16_t int16_Return;


  switch(*puint8_JobNum){
  case 0:
    STC_uint8_JobNum_USW = 0;  // USERスイッチ検出処理番号初期化


    (*puint8_JobNum)++;  // 次の処理番号に移行する。
    int16_Return = -1;   // 処理継続
    break;

  case 1:
    //-----------------------------------------------------------
    // USERスイッチ押下検出
    //-----------------------------------------------------------
    // 引数：
    // uint8_t *puint8_JobNum : 処理番号が格納された変数のポインタ


    // 戻り値：
    //   -1 : 検出なし
    //    0 : 検出あり
    //-----------------------------------------------------------
    int16_Return = def_M_Detect_USW(&STC_uint8_JobNum_USW);
    if(int16_Return == -1){
      // 検出なし
      break;  // 処理番号維持 : 処理継続 : 現在の処理番号をループ
    }


    (*puint8_JobNum)++;  // 次の処理番号に移行する。
    int16_Return = -1;   // 処理継続
    break;

  case 2:
    //---------------------------------------------------------
    // ST LED点滅フラグ更新
    //---------------------------------------------------------
    // 引数：
    // int16_t *pint16_Flag_Blink_LED_ST : ST LED点滅フラグの変数のポインタ

    // struct sParam_Blink_LED_ST *pstructParam_Blink_LED_ST :
    //              ST LED点滅用パラメータの構造体のポインタ


    // 戻り値:
    //    なし
    //---------------------------------------------------------
    Renew_Flag_Blink_LED_ST(&GLB_int16_Flag_Blink_LED_ST,
                            pstructParam_Blink_LED_ST);


    *puint8_JobNum = 1;  // USERスイッチ検出処理に移行する。: case 1:
    int16_Return = 0;    // OK : 処理が1回終了
    break;  // case 1: と case 2: を繰り返し実行する。

  default:
    *puint8_JobNum = 0;  // 処理番号初期化
    int16_Return = 1;    // NG終了
    break;
  }

  return(int16_Return);
}



//---------------------------------------------------------
// ST LED点滅フラグ更新
//---------------------------------------------------------
// 引数：
// int16_t *pint16_Flag_Blink_LED_ST :
//                      ST LED点滅フラグの変数のポインタ

// struct sParam_Blink_LED_ST *pstructParam_Blink_LED_ST :
//              ST LED点滅用パラメータの構造体のポインタ


// 戻り値:
//    なし
//---------------------------------------------------------
void Renew_Flag_Blink_LED_ST(int16_t *pint16_Flag_Blink_LED_ST,
            struct sParam_Blink_LED_ST *pstructParam_Blink_LED_ST)
{
    //-------------------------------------
    // LED点滅フラグ
    //-------------------------------------
    //  0 : 点灯1000mSec / 消灯2000mSec
    //  1 : 点灯100mSec / 消灯100mSec
    //  2 : 点灯200mSec / 消灯200mSec
    //  3 : 点灯300mSec / 消灯300mSec
    //  4 : 点灯400mSec / 消灯400mSec
    //  5 : 点灯500mSec / 消灯500mSec
    //-------------------------------------
    (*pint16_Flag_Blink_LED_ST)++;  // LED点滅フラグ + 1
    if(*pint16_Flag_Blink_LED_ST > 5){
      // 5 を超えたら 0 にする。 : 0 ～ 5 の値を繰り返す。
      *pint16_Flag_Blink_LED_ST = 0;  // LED点滅フラグに0をセット
    }

    //-----------------------------------------------------
    // LED点滅フラグ : *pint16_Flag_Blink_LED_ST の値により
    // 点滅間隔を設定する。
    //-----------------------------------------------------
    switch(*pint16_Flag_Blink_LED_ST)
    {
    case 0:
      //------------------------------------------------
      // LED(緑) : 点灯1000mSec / 消灯2000mSec
      //------------------------------------------------
      pstructParam_Blink_LED_ST->uint16_Time_LED_ST_ON = (uint16_t)1000;
      pstructParam_Blink_LED_ST->uint16_Time_LED_ST_OFF = (uint16_t)2000;
      //------------------------------------------------

      break;

    case 1:
      //------------------------------------------------
      // LED(緑) : 点灯100mSec / 消灯100mSec
      //------------------------------------------------
      pstructParam_Blink_LED_ST->uint16_Time_LED_ST_ON = (uint16_t)100;
      pstructParam_Blink_LED_ST->uint16_Time_LED_ST_OFF = (uint16_t)100;
      //------------------------------------------------

      break;

    case 2:
      //------------------------------------------------
      // LED(緑) : 点灯200mSec / 消灯200mSec
      //------------------------------------------------
      pstructParam_Blink_LED_ST->uint16_Time_LED_ST_ON = (uint16_t)200;
      pstructParam_Blink_LED_ST->uint16_Time_LED_ST_OFF = (uint16_t)200;
      //------------------------------------------------

      break;

    case 3:
      //------------------------------------------------
      // LED(緑) : 点灯300mSec / 消灯300mSec
      //------------------------------------------------
      pstructParam_Blink_LED_ST->uint16_Time_LED_ST_ON = (uint16_t)300;
      pstructParam_Blink_LED_ST->uint16_Time_LED_ST_OFF = (uint16_t)300;
      //------------------------------------------------

      break;

    case 4:
      //------------------------------------------------
      // LED(緑) : 点灯400mSec / 消灯400mSec
      //------------------------------------------------
      pstructParam_Blink_LED_ST->uint16_Time_LED_ST_ON = (uint16_t)400;
      pstructParam_Blink_LED_ST->uint16_Time_LED_ST_OFF = (uint16_t)400;
      //------------------------------------------------

      break;

    case 5:
      //------------------------------------------------
      // LED(緑) : 点灯500mSec / 消灯500mSec
      //------------------------------------------------
      pstructParam_Blink_LED_ST->uint16_Time_LED_ST_ON = (uint16_t)500;
      pstructParam_Blink_LED_ST->uint16_Time_LED_ST_OFF = (uint16_t)500;
      //------------------------------------------------

      break;

    default:
      //------------------------------------------------
      // LED(緑) : 点灯1000mSec / 消灯2000mSec
      //------------------------------------------------
      pstructParam_Blink_LED_ST->uint16_Time_LED_ST_ON = (uint16_t)1000;
      pstructParam_Blink_LED_ST->uint16_Time_LED_ST_OFF = (uint16_t)2000;
      //------------------------------------------------

      break;
    }

    pstructParam_Blink_LED_ST->int16_Restart_LED_ST = 1;  // LED再起動フラグON
}
