﻿/*
 * Blink_LED_ST.c
 *
 *  Created on: 2024/12/19
 *      Author: egaono-electronics
 */

#include "Blink_LED_ST.h"
#include "Time_Interval.h"



//------------------------------------------------------
// ST LED点滅用パラメータの構造体の宣言
//------------------------------------------------------
struct sParam_Blink_LED_ST GLB_structParam_Blink_LED_ST;



//--------------------------------------------------
// ST LEDのGPIO初期化
//--------------------------------------------------
// 引数:
//    なし


// 戻り値:
//    なし
//--------------------------------------------------
void Initialize_LED_ST(void)
{
   GPIO_InitTypeDef GPIO_InitStruct = {0};

  // GPIO Ports Clock Enable
  def_GPIOx_CLK_ENABLE_LED_ST();


  //----------------------------------------
  // LED OFF : Lowを出力
  //----------------------------------------
  HAL_GPIO_WritePin(def_GPIOx_LED_ST,
                    def_GPIO_PIN_x_LED_ST,
                    GPIO_PIN_RESET);

  //------------------------------------------------
  // GPIOの指定ピンを出力に初期化する。
  //------------------------------------------------
  GPIO_InitStruct.Pin = def_GPIO_PIN_x_LED_ST;
  GPIO_InitStruct.Mode = GPIO_MODE_OUTPUT_PP;
  GPIO_InitStruct.Pull = GPIO_NOPULL;
  GPIO_InitStruct.Speed = GPIO_SPEED_FREQ_LOW;
  HAL_GPIO_Init(def_GPIOx_LED_ST, &GPIO_InitStruct);
}



//--------------------------------------------------
// ST LED点灯
//--------------------------------------------------
// 引数:
//    なし


// 戻り値:
//    なし
//--------------------------------------------------
void LED_ST_ON(void)
{
  // ST LED ON : Highを出力
  HAL_GPIO_WritePin(def_GPIOx_LED_ST,
                    def_GPIO_PIN_x_LED_ST,
                    GPIO_PIN_SET);
}



//--------------------------------------------------
// ST LED消灯
//--------------------------------------------------
// 引数:
//    なし


// 戻り値:
//    なし
//--------------------------------------------------
void LED_ST_OFF(void)
{
  // ST LED OFF : Lowを出力
  HAL_GPIO_WritePin(def_GPIOx_LED_ST,
                    def_GPIO_PIN_x_LED_ST,
                    GPIO_PIN_RESET);
}



//----------------------------------------------------------
// ST LED点滅
//----------------------------------------------------------
// 引数:
// uint8_t *puint8_JobNum : 処理番号を格納する変数のポインタ

// struct sParam_Blink_LED_ST *pstructParam_Blink_LED_ST :
//              ST LED点滅用パラメータの構造体のポインタ


// 戻り値:
//   -1 : 処理中
//    0 : OK終了
//    1 : NG
//----------------------------------------------------------
int16_t Blink_LED_ST(uint8_t *puint8_JobNum,
            struct sParam_Blink_LED_ST *pstructParam_Blink_LED_ST)
{
  //----------------------------------------------------
  // 呼び出す関数の引数に使用する処理番号は、
  // 必ず static の変数宣言をしてください。
  //----------------------------------------------------
  static uint8_t STC_uint8_JobNum_Time;  // Time_Interval処理番号

  //--------------------------------------------------------
  // Time_Interval用パラメータの構造体の宣言は、
  // 使用する関数内で、必ず static で宣言してください。
  //--------------------------------------------------------
  // Time_Interval用パラメータの構造体の宣言
  //--------------------------------------------------------
  static struct sParam_Time_Interval STC_structParam_Time_Interval;


  int16_t int16_Return;


  //--------------------------------------------------------
  // ST LED再起動フラグチェック
  //--------------------------------------------------------
  if(pstructParam_Blink_LED_ST->int16_Restart_LED_ST == 1){
    // ST LED再起動フラグONの場合
    *puint8_JobNum = 1;  // 処理番号を 1 にする。

    pstructParam_Blink_LED_ST->int16_Restart_LED_ST = 0;
                            // ST LED再起動フラグOFF
  }
  //--------------------------------------------------------


  switch(*puint8_JobNum)
  {
  case 0:
    //--------------------------------------------------
    // 1回だけ case 0: を実行します。

    // その後は、case 1: を実行後、
    // case 2: ～ case 3: をループします。
    //--------------------------------------------------


    //----------------------------------------------------------
    // ST LED点滅処理用パラメータ初期化
    //----------------------------------------------------------
    pstructParam_Blink_LED_ST->int16_LED_ST_Init_Done = 0;
                            // ST LED 初期化済みフラグ

    pstructParam_Blink_LED_ST->int16_Restart_LED_ST = 0;
                            // ST LED再起動フラグ

    pstructParam_Blink_LED_ST->uint16_Time_LED_ST_ON = 1000;
                            // ST LED点灯時間(mSec)
    pstructParam_Blink_LED_ST->uint16_Time_LED_ST_OFF = 2000;
                            // ST LED消灯時間(mSec)
    //----------------------------------------------------------


    (*puint8_JobNum)++;  // 次の処理番号に移行する。
    int16_Return = -1;   // 処理継続
    break;

  case 1:
    //------------------------------------------------------
    // 最初の 1回目は無条件で case 1: を実行します。

    // その後は ST LED再起動フラグ が ON になった場合に
    // 実行します。
    //------------------------------------------------------


    // ST LED 初期化済みフラグ判定
    if(pstructParam_Blink_LED_ST->int16_LED_ST_Init_Done != 1){
      // ST LED が初期化済みでない場合

      //------------------------------------------------
      // ST LEDのGPIO初期化
      //------------------------------------------------
      Initialize_LED_ST();


      pstructParam_Blink_LED_ST->int16_LED_ST_Init_Done = 1;
                        // ST LED 初期化済み をセット
    }


    //----------------------------------------------
    // ST LED点灯
    //----------------------------------------------
    LED_ST_ON();


    STC_uint8_JobNum_Time = 0;  // Time_Interval処理番号初期化
    STC_structParam_Time_Interval.uint32_Interval
        = (uint32_t)pstructParam_Blink_LED_ST->uint16_Time_LED_ST_ON;
                                        // 待ち時間セット


    (*puint8_JobNum)++;  // 次の処理番号に移行する。
    int16_Return = -1;   // 処理継続
    break;

  case 2:
    //----------------------------------------------------------
    // 時間待ち : 単位 mSec
    //----------------------------------------------------------
    // 戻り値が -1 以外になるまで、繰り返し呼び出してください。
    //----------------------------------------------------------
    // 引数:
    // uint8_t *puint8_JobNum : 処理番号を格納する変数のポインタ

    // struct sParam_Time_Interval *pstructParam_Time_Interval :
    //              Time_Interval用パラメータの構造体のポインタ


    // 戻り値:
    //   -1 : 処理中 : 時間が経過していない。
    //    0 : OK終了 : 時間が経過した。
    //    1 : NG終了
    //----------------------------------------------------------
    int16_Return = Time_Interval(&STC_uint8_JobNum_Time,
                                 &STC_structParam_Time_Interval);
    if(int16_Return == -1){
      // 処理中 : 時間未経過
      break;  // 処理番号維持 : 処理継続 : 現在の処理番号をループ
    }


    //----------------------------------------------
    // ST LED消灯
    //----------------------------------------------
    LED_ST_OFF();


    STC_uint8_JobNum_Time = 0;  // Time_Interval処理番号初期化
    STC_structParam_Time_Interval.uint32_Interval
        = (uint32_t)pstructParam_Blink_LED_ST->uint16_Time_LED_ST_OFF;
                                        // 待ち時間セット


    (*puint8_JobNum)++;  // 次の処理番号に移行する。
    int16_Return = -1;   // 処理継続
    break;

  case 3:
    //----------------------------------------------------------
    // 時間待ち : 単位 mSec
    //----------------------------------------------------------
    // 戻り値が -1 以外になるまで、繰り返し呼び出してください。
    //----------------------------------------------------------
    // 引数:
    // uint8_t *puint8_JobNum : 処理番号を格納する変数のポインタ

    // struct sParam_Time_Interval *pstructParam_Time_Interval :
    //              Time_Interval用パラメータの構造体のポインタ


    // 戻り値:
    //   -1 : 処理中 : 時間が経過していない。
    //    0 : OK終了 : 時間が経過した。
    //    1 : NG終了
    //----------------------------------------------------------
    int16_Return = Time_Interval(&STC_uint8_JobNum_Time,
                                 &STC_structParam_Time_Interval);
    if(int16_Return == -1){
      // 処理中 : 時間未経過
      break;  // 処理番号維持 : 処理継続 : 現在の処理番号をループ
    }


    //------------------------------------------------
    // ST LED点灯
    //------------------------------------------------
    LED_ST_ON();


    STC_uint8_JobNum_Time = 0;  // Time_Interval処理番号初期化
    STC_structParam_Time_Interval.uint32_Interval
        = (uint32_t)pstructParam_Blink_LED_ST->uint16_Time_LED_ST_ON;
                                        // 待ち時間セット


    *puint8_JobNum = 2;  // 処理番号 2 に移行する。: case 2:
                         // case 2: ～ case 3: をループ
    int16_Return = -1;   // 処理継続
    break;

  default:
    *puint8_JobNum = 0;   // 処理番号初期化
    int16_Return = 1;     // NG終了
    break;
  }

  return(int16_Return);
}
